# Arrange
A python script that moves files from the specified directory
(default is downloads) to the appropriate directory according to
the file's extension.

For example files ending in `png` or `jpg` are moved
to Pictures, files ending in mp4 or mvk get moved to Videos and so
on and so forth...

## Installation
`pip install arranger`
